Vottorð | OiRA
Description: Það fer eftir þeirri nálgun sem landsskrifstofa OiRA/hugbúnaðarhönnuðurinn hefur tekið hvort hægt sé að fá vottorð um áhættumatið. Upplýsingar um kosti slíkra vottorða má fá hjá landsskrifstofu OiRA.

Þemu

# Vottorð

Það fer eftir þeirri nálgun sem landsskrifstofa OiRA/hugbúnaðarhönnuðurinn hefur tekið hvort hægt sé að fá vottorð um áhættumatið. Upplýsingar um kosti slíkra vottorða má fá hjá landsskrifstofu OiRA.

Hvernig á að fá vottorð

## Framkvæmdu heildstætt áhættumat

Þegar þú ferð í gegnum áhættumatið mun OiRA skrásetja framvinduna. Þegar þú hefur lagt mat á tiltekinn áhættufjölda mun verkærið láta þig vita um möguleika á því að fá vottorð þegar öllu áhættumatinu er lokið. Hver landsskrifstofa OiRA/hugbúnaðarhönnuður ákveður þröskuldinn (hlutfallið) fyrir skilgreiningunni á „heildstæðu“ áhættumati. Vottorðið má fá í gegnum hnappinn „staða“ í valmyndinni til vinstri á skjánum.

The status page shows that a certificate is available.

## Skoða og birta vottorð

Þegar þú smellir á hnappinn „skoða vottorð“ verður þú beðin/n um að skrá nafn fyrirtækisins sem birtist á vottorðinu. Það fer eftir innlendum ákvörðunum hvort þú verður beðin/n um frekari upplýsingar til að tryggja að vottorðið innihaldi allar nauðsynlegar upplýsingar.

Enter all information needed for the certificate.

Ef þú hakar við reitinn „birta“ mun einkvæmt veffang (URL) á vottorðið þitt birtast. Afritaðu hlekkinn og deildu honum með viðeigandi einstaklingum sem sönnun á því að þú hafir framkvæmt áhættumat.

Athugaðu: Aðeins upplýsingar, sem birtast á þessari síðu, verða opinberar almenningi. Ekki er hægt að finna hlekkinn í valmynd OiRA vefsíðunnar –- hann er aðeins fyrir þig. En fræðilega séð geta allir sem vafra um netið séð vottorðið sem þú bjóst til!

Vottorðið sýnir aðeins að þú hafir brugðist við tilteknum áhættufjölda í áhættumatsverkfærinu og veitir engar aðrar upplýsingar. Aðeins þú og enginn annar getur skoðað tiltekin svör, sem þú veittir, úr áhættumatinu í gegnum OiRA verkfærið.

Scroll to top Load toolbar…
Back

## certificates.md

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More